@@ -88,7 +88,7 @@ class OTRSClient():
                 article=article,
                 dynamic_fields=dynamic_fields)
         except (HTTPError, APIError, ResponseParseError, SessionNotCreated, ArgumentMissingError) as error:
-            raise TicketNotCreated(error.message)
+            raise TicketNotCreated(error.message, dynamic_fields)
         return OTRSCreationTicketResponse(client_response)
 
     def get_otrs_process_ticket(self, ticket_id):
