@@ -15,7 +15,7 @@ class FiberDynamicFields(InternetDynamicFields):
         ]
 
     def _df_previous_contract_pon(self):
-        return DynamicField(name="IDtryton", value=self.service_data.previous_contract_pon)
+        return DynamicField(name="ponAntic", value=self.service_data.previous_contract_pon)
 
     def _df_previous_contract_fiber_speed(self):
         return DynamicField(
