@@ -20,6 +20,10 @@ class MobileDynamicFields(ProvisionDynamicFields):
             self._has_sim(),
             self._sim_received(),
             self._send_sim_type(),
+            self._delivery_street(),
+            self._delivery_zip_code(),
+            self._delivery_city(),
+            self._delivery_state(),
         ]
 
     def _line(self):
@@ -32,7 +36,7 @@ class MobileDynamicFields(ProvisionDynamicFields):
         return DynamicField("ICCdonant", self.service_data.icc)
 
     def _service_type(self):
-        if self.service_data.portability:
+        if self.service_data.type == 'portability':
             return DynamicField("tipusServeiMobil", "portabilitat")
         else:
             return DynamicField("tipusServeiMobil", "altaNova")
@@ -73,6 +77,18 @@ class MobileDynamicFields(ProvisionDynamicFields):
     def _subdivision(self):
         return DynamicField("provinciaMobil", self.customer_data.subdivision)
 
+    def _delivery_street(self):
+        return DynamicField("direccioEnviament", self.service_data.delivery_street)
+
+    def _delivery_city(self):
+        return DynamicField("poblacioEnviament", self.service_data.delivery_city)
+
+    def _delivery_zip_code(self):
+        return DynamicField("CPenviament", self.service_data.delivery_zip_code)
+
+    def _delivery_state(self):
+        return DynamicField("provinciaEnviament", self.service_data.delivery_state)
+
     def _product(self):
         return DynamicField(
             name="productMobil",
