@@ -1,6 +1,7 @@
 from otrs_somconnexio.otrs_models.adsl_ticket import ADSLTicket
 from otrs_somconnexio.otrs_models.fiber_ticket import FiberTicket
 from otrs_somconnexio.otrs_models.mobile_ticket import MobileTicket
+from otrs_somconnexio.otrs_models.router_4G_ticket import Router4GTicket
 from otrs_somconnexio.exceptions import ServiceTypeNotAllowedError
 
 
@@ -20,6 +21,8 @@ class TicketFactory(object):
             TicketClass = FiberTicket
         elif self.service_data.service_type == 'mobile':
             TicketClass = MobileTicket
+        elif self.service_data.service_type == '4G':
+            TicketClass = Router4GTicket
         else:
             raise ServiceTypeNotAllowedError(self.service_data.order_id, self.service_data.service_type)
 
