@@ -19,7 +19,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'phone_number',
             'sc_icc',
             'icc',
-            'portability',
+            'type',
             'previous_provider',
             'previous_owner_name',
             'previous_owner_surname',
@@ -27,6 +27,10 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'product',
             'notes',
             'has_sim',
+            'delivery_street',
+            'delivery_city',
+            'delivery_zip_code',
+            'delivery_state',
         ])
         customer_data = Mock(spec=[
             'id',
@@ -39,7 +43,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'zip',
             'subdivision'])
 
-        mobile_data.type = 'mobile'
+        mobile_data.service_type = 'mobile'
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
@@ -86,14 +90,14 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
             'orange_fiber_coverage',
-            'change_address',
+            'type',
             'landline_phone_number',
             'product',
             'previous_internal_provider',
         ])
         customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'phone'])
 
-        service_data.type = 'adsl'
+        service_data.service_type = 'adsl'
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
@@ -143,13 +147,13 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
             'orange_fiber_coverage',
-            'change_address',
+            'type',
             'product',
             'previous_internal_provider',
         ])
         customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'phone'])
 
-        service_data.type = 'fiber'
+        service_data.service_type = 'fiber'
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
