@@ -32,7 +32,7 @@ class FiberDataTestCase(unittest.TestCase):
             mm_fiber_coverage=None,
             vdf_fiber_coverage=None,
             orange_fiber_coverage=None,
-            change_address="no",
+            type="new",
             product="product",
             previous_contract_address="Old street",
             previous_contract_phone="62626826",
