@@ -6,9 +6,9 @@ from otrs_somconnexio.otrs_models.fiber_dynamic_fields import FiberDynamicFields
 
 def dynamic_fields_to_dct(dynamic_fields):
     """
-    Convert the MobileDynamicFields object in a dict with the name of the dynamic
+    Convert the FiberDynamicFields object in a dict with the name of the dynamic
     field as key and the value as value.
-    Only used to test the MobileDynamicFields object.
+    Only used to test the FiberDynamicFields object.
     """
     dct = {}
     for df in dynamic_fields:
@@ -52,25 +52,24 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
             'orange_fiber_coverage',
-            'change_address',
+            'type',
             'product',
             'previous_internal_provider',
-            'change_address',
         ])
 
-        self.adsl_otrs_process_id = "ADSLProcessID"
-        self.adsl_otrs_activity_id = "ADSLActivityID"
+        self.fiber_otrs_process_id = "FiberProcessID"
+        self.fiber_otrs_activity_id = "FiberActivityID"
 
     def test_process_id_field(self):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["ProcessManagementProcessID"], "ADSLProcessID")
+        self.assertEqual(dynamic_fields_dct["ProcessManagementProcessID"], "FiberProcessID")
 
     def test_previous_phone_field(self):
         self.service_data.previous_contract_phone = "666666666"
@@ -78,8 +77,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -94,8 +93,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -110,8 +109,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -126,8 +125,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -140,20 +139,20 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["ProcessManagementActivityID"], "ADSLActivityID")
+        self.assertEqual(dynamic_fields_dct["ProcessManagementActivityID"], "FiberActivityID")
 
     # TODO: Are we using this field?????
     def test_contract_id_field(self):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -165,8 +164,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -178,8 +177,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -191,8 +190,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -204,8 +203,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -217,8 +216,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -230,8 +229,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -243,8 +242,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -252,13 +251,12 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
     def test_previous_provider_field(self):
         self.service_data.previous_provider = "SomConnexio"
-        self.service_data.change_address = "no"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -270,8 +268,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -283,8 +281,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -296,8 +294,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -309,8 +307,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -322,8 +320,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -335,8 +333,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -348,8 +346,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -361,8 +359,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -374,8 +372,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -387,8 +385,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -400,8 +398,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -413,8 +411,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -426,8 +424,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -439,8 +437,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -452,8 +450,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -465,8 +463,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -478,42 +476,57 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["coberturaFibraOrange"], "fibraFTTH")
 
-    def test_change_address_field(self):
-        self.service_data.change_address = "yes"
+    def test_type_field_location_change(self):
+        self.service_data.type = "location_change"
         self.service_data.previous_owner_name = "A"
         self.service_data.previous_owner_surname = "B"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "yes")
         self.assertEqual(dynamic_fields_dct["nomCognomSociAntic"], "A B")
 
-    def test_change_address_field_not_set(self):
-        self.service_data.change_address = "no"
+    def test_type_field_non_location_change(self):
+        self.service_data.type = "portability"
+        self.service_data.previous_owner_name = "A"
+        self.service_data.previous_owner_surname = "B"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "no")
-        self.assertFalse(dynamic_fields_dct.get("nomCognomSociAntic"))
+        self.assertNotIn("nomCognomSociAntic", dynamic_fields_dct.keys())
+
+    def test_previous_provider_does_not_exist_when_location_change(self):
+        self.service_data.type = 'location_change'
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertNotIn("proveidorPrevi", dynamic_fields_dct.keys())
 
     def test_product_field(self):
         self.service_data.product = "FIBRA100"
@@ -521,8 +534,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -534,22 +547,9 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["proveidorPreviCU"], "SC-MM")
-
-    def test_previous_provider_not_exists_in_change_address(self):
-        self.service_data.change_address = True
-
-        dynamic_fields = FiberDynamicFields(
-            self.service_data,
-            self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertNotIn("proveidorPrevi", dynamic_fields_dct.keys())
