@@ -98,10 +98,9 @@ class FiberTicketTestCase(unittest.TestCase):
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
             'orange_fiber_coverage',
-            'change_address',
+            'type',
             'product',
             'previous_internal_provider',
-            'change_address',
         ])
 
         mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
