@@ -16,12 +16,16 @@ class MobileDataTestCase(unittest.TestCase):
             previous_owner_vat="740227654G",
             previous_owner_name="name",
             previous_owner_surname="surname",
-            portability=False,
+            type='new',
             sc_icc="123456789",
             icc=None,
             product="product",
             notes="Mobile crm lead line",
             has_sim=True,
+            delivery_street='Les Moreres',
+            delivery_city='Alacant',
+            delivery_zip_code='03140',
+            delivery_state='ES-A',
         )
 
         self.assertIsInstance(mobile_data, MobileData)
