@@ -37,15 +37,20 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             'sc_icc',
             'icc',
             'service_internet_unlimited',
-            'portability',
+            'type',
             'previous_owner_vat',
             'previous_owner_name',
             'previous_owner_surname',
             'previous_provider',
             'product',
             'has_sim',
+            'type',
+            'delivery_street',
+            'delivery_city',
+            'delivery_zip_code',
+            'delivery_state',
         ])
-        self.mobile_data.portability = False
+        self.mobile_data.type = 'new'
 
         self.mobile_otrs_process_id = "MobileProcessID"
         self.mobile_otrs_activity_id = "MobileActivityID"
@@ -151,7 +156,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["ICCdonant"], "4321")
 
     def test_service_type_field_new(self):
-        self.mobile_data.portability = False
+        self.mobile_data.type = 'new'
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
@@ -164,7 +169,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["tipusServeiMobil"], "altaNova")
 
     def test_service_type_field_portability(self):
-        self.mobile_data.portability = True
+        self.mobile_data.type = 'portability'
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
@@ -371,3 +376,56 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["provinciaMobil"], "ES-A")
+
+    def test_delivery_street_field(self):
+        self.mobile_data.delivery_street = "Les Moreres"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["direccioEnviament"], "Les Moreres")
+
+    def test_delivery_city_field(self):
+        self.mobile_data.delivery_city = "Alacant"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["poblacioEnviament"], "Alacant")
+
+    def test_delivery_zip_code_field(self):
+        self.mobile_data.delivery_zip_code = "03140"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["CPenviament"], "03140")
+
+    def test_delivery_state_field(self):
+        self.mobile_data.delivery_state = "ES-A"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["provinciaEnviament"], "ES-A")
+
