@@ -46,8 +46,8 @@ class MobileTicketTestCase(unittest.TestCase):
         MobileTicket(mobile_data, customer_data)._build_article()
 
         MockProvisionArticle.assert_called_with(
-            'mobile', 
-            mobile_data.order_id, 
+            'mobile',
+            mobile_data.order_id,
             mobile_data.notes
         )
         mock_mobile_article.call.assert_called_once()
@@ -78,7 +78,7 @@ class MobileTicketTestCase(unittest.TestCase):
             'phone_number',
             'sc_icc',
             'icc',
-            'portability',
+            'type',
             'previous_provider',
             'previous_owner_vat',
             'previous_owner_name',
@@ -86,9 +86,14 @@ class MobileTicketTestCase(unittest.TestCase):
             'product',
             'notes',
             'has_sim',
+            'type',
+            'delivery_street',
+            'delivery_city',
+            'delivery_zip_code',
+            'delivery_state',
         ])
         mobile_data.order_id = 4321
-        mobile_data.portability = False
+        mobile_data.type = 'new'
 
         customer_data = Mock(spec=[
             'id',
